var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { Component, Inject } from '@angular/core';
import { FormControl } from '@angular/forms';
import { SANDBOXES } from './shared/tokens';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/distinctUntilChanged';
import { StateService } from './shared/state.service';
export var AppComponent = (function () {
    function AppComponent(sandboxes, stateService) {
        var _this = this;
        this.stateService = stateService;
        this.filter = new FormControl();
        this.totalSandboxes = sandboxes.length;
        this.filteredSandboxes = this.filterSandboxes(sandboxes, this.stateService.getFilter());
        var _a = this.stateService.getSelectedSandboxAndScenarioKeys(), sandboxKey = _a.sandboxKey, scenarioKey = _a.scenarioKey;
        this.selectScenario(sandboxKey, scenarioKey);
        this.filter.setValue(this.stateService.getFilter());
        this.filter.valueChanges
            .debounceTime(300)
            .distinctUntilChanged()
            .subscribe(function (value) {
            _this.filteredSandboxes = _this.filterSandboxes(sandboxes, value);
            _this.stateService.setFilter(value);
            if (!value) {
                _this.selectScenario(null, null);
            }
        });
    }
    AppComponent.prototype.filterSandboxes = function (sandboxes, filter) {
        if (!filter) {
            return [];
        }
        return sandboxes
            .filter(function (sandbox) { return sandbox.name.toLowerCase().indexOf(filter.toLowerCase()) >= 0; })
            .sort(function (a, b) {
            var nameA = a.name.toUpperCase();
            var nameB = b.name.toUpperCase();
            if (nameA < nameB) {
                return -1;
            }
            if (nameA > nameB) {
                return 1;
            }
            return 0;
        });
    };
    AppComponent.prototype.selectScenario = function (sandboxKey, scenarioKey) {
        this.selectedSandboxAndScenarioKeys = { sandboxKey: sandboxKey, scenarioKey: scenarioKey };
        this.stateService.setSandboxAndScenarioKeys(this.selectedSandboxAndScenarioKeys);
    };
    AppComponent = __decorate([
        Component({
            selector: 'ap-root',
            template: "\n    <aside>\n      <header>Angular Playground</header>\n      <input type=\"text\" name=\"filter\" placeholder=\"filter\" [formControl]=\"filter\">\n      <div *ngFor=\"let sandbox of filteredSandboxes\">\n        <span class=\"sandbox\"\n              [class.selected]=\"selectedSandboxAndScenarioKeys?.sandboxKey === sandbox.key\">\n          {{sandbox.prependText}}{{sandbox.name}}</span>\n        <div *ngFor=\"let scenario of sandbox.scenarios\"\n             (click)=\"selectScenario(sandbox.key, scenario.key)\">\n          <a class=\"scenario\"\n             [class.selected]=\"selectedSandboxAndScenarioKeys?.scenarioKey === scenario.key && selectedSandboxAndScenarioKeys?.sandboxKey === sandbox.key\">\n            {{scenario.description}}</a>\n        </div>\n      </div>\n      <div *ngIf=\"filteredSandboxes.length === 0\" class=\"help-message\">\n        <template [ngIf]=\"totalSandboxes > 0\">\n          <p>The app has {{totalSandboxes}} sandboxed component{{totalSandboxes > 1 ? 's' : ''}} loaded.</p>\n          <p *ngIf=\"totalSandboxes > 1\">Use the filter to find one to play in!</p>\n          <p *ngIf=\"totalSandboxes === 1\">Use the filter to find it!</p>\n        </template>\n        <template [ngIf]=\"totalSandboxes === 0\">\n          <p>The app does not have any sandboxed components.</p>\n        </template>\n      </div>\n    </aside>\n    <section>\n      <ap-scenario [selectedSandboxAndScenarioKeys]=\"selectedSandboxAndScenarioKeys\"></ap-scenario>\n    </section>\n  ",
            styles: ["\n    :host {\n      font-family: sans-serif;\n      display: flex;\n      height: 100vh; }\n      :host input {\n        color: inherit;\n        font: inherit;\n        margin: 0; }\n      :host input::-moz-focus-inner {\n        border: 0;\n        padding: 0; }\n      :host input {\n        line-height: normal; }\n      :host aside {\n        width: 200px;\n        min-width: 200px;\n        padding: 14px;\n        background-color: #ebebeb; }\n        :host aside header {\n          border: 2px solid #666;\n          font-size: .8em;\n          text-transform: uppercase;\n          padding: 4px;\n          text-align: center;\n          margin-bottom: 4px; }\n        :host aside input[type=\"text\"] {\n          margin-bottom: 4px;\n          width: 196px; }\n        :host aside a {\n          cursor: pointer; }\n        :host aside .sandbox.selected, :host aside .scenario.selected {\n          font-weight: bold; }\n        :host aside .scenario {\n          font-size: .8em;\n          padding: 0 8px; }\n        :host aside .help-message {\n          text-align: center;\n          font-style: italic;\n          font-size: .9em;\n          color: #999;\n          padding: 40px 10px; }\n      :host section {\n        border: 0;\n        width: 100%;\n        background-color: white; }\n  "]
        }),
        __param(0, Inject(SANDBOXES)), 
        __metadata('design:paramtypes', [Array, StateService])
    ], AppComponent);
    return AppComponent;
}());
